import * as https from 'https';
import https__default from 'https';
import pino from 'pino';
import { ErrorResponse } from '@apollo/client/link/error';
import * as node_fetch from 'node-fetch';
import { Response as Response$1 } from 'node-fetch';
import AsyncRetry from 'async-retry';
import z, { ZodTypeDef } from 'zod';

declare function createHttpsAgent(pfxFilePath: string, passphraseFilePath: string): Promise<https.Agent>;

declare enum RecoverableBehaviour {
    RECOVERABLE = "RECOVERABLE",
    UNRECOVERABLE = "UNRECOVERABLE"
}
type ExceptHttpStatusConfig = {
    httpStatus: number;
    conditionFn?: (errorBody: any) => boolean;
};
type HttpClientResponseHandlerOptions = {
    defaultRecoverableBehaviour: RecoverableBehaviour;
    exceptHttpStatusConfig?: Array<ExceptHttpStatusConfig>;
    allowedStatusCodes?: Array<number>;
};
type HandleErrorResponse<R = Response | Response$1> = (response: R, retryCount?: number) => Promise<void>;
declare const initHttpResponseHandler: (options: HttpClientResponseHandlerOptions, rootLogger: pino.Logger) => HandleErrorResponse;

declare const initGraphQlHttpResponseHandler: (options: HttpClientResponseHandlerOptions, rootLogger: pino.Logger) => (errorResponse: ErrorResponse) => void;

declare class RecoverableServiceError extends Error {
    rootCause: any;
    status?: number;
    constructor(message: string, rootCause?: any, status?: number);
}

declare class UnrecoverableServiceError extends Error {
    rootCause: any;
    status?: number;
    constructor(message: string, rootCause?: any, status?: number);
}

declare const fetchAndRetry: <R>({ fetchFn, retryOptions, handleErrorResponseFn, }: {
    fetchFn: () => Promise<R>;
    retryOptions: AsyncRetry.Options;
    handleErrorResponseFn: HandleErrorResponse<R>;
}) => Promise<R>;
declare const createDefaultErrorResponseHandler: (log: pino.Logger) => HandleErrorResponse<Response | node_fetch.Response>;
type AgentRequestInit = RequestInit & {
    agent?: https__default.Agent;
};
type FetchUserHeader = {
    'cp-axa-user-id': string;
    'cp-axa-user-role': string;
};
declare const fetchJson: (input: RequestInfo | URL, init?: AgentRequestInit, userHeaders?: FetchUserHeader) => () => Promise<Response>;
type FetchJsonWithRetryRequest<ZodOutput, ZodInput> = {
    fetch: {
        input: RequestInfo | URL;
        init?: AgentRequestInit;
        user?: FetchUserHeader;
    };
    retryOptions: AsyncRetry.Options;
    log: pino.Logger;
    handleErrorResponseFn?: HandleErrorResponse;
    validator: z.ZodType<ZodOutput, ZodTypeDef, ZodInput>;
};
declare const fetchJsonWithRetry: <ZodOutput, ZodInput>({ fetch, log, handleErrorResponseFn, validator, retryOptions, }: FetchJsonWithRetryRequest<ZodOutput, ZodInput>) => Promise<ZodOutput>;
declare const fetchJsonFeignWithRetry: <ZodOutput, ZodInput>(fetchJsonWithRetryRequest: FetchJsonWithRetryRequest<ZodOutput, ZodInput>) => Promise<ZodOutput>;

type AxaContextHeaderV2Arguments = {
    clientId: string;
    audition?: string;
    issuedAt?: Date;
};
declare const FEIGN_HEADERS: {
    'cp-axa-user-id': string;
    'cp-axa-user-role': string;
};
declare const createXAxaContextHeaderV2: ({ clientId, audition, issuedAt, }: AxaContextHeaderV2Arguments) => string;

export { type ExceptHttpStatusConfig, FEIGN_HEADERS, type FetchJsonWithRetryRequest, type FetchUserHeader, type HandleErrorResponse, type HttpClientResponseHandlerOptions, RecoverableBehaviour, RecoverableServiceError, UnrecoverableServiceError, createDefaultErrorResponseHandler, createHttpsAgent, createXAxaContextHeaderV2, fetchAndRetry, fetchJson, fetchJsonFeignWithRetry, fetchJsonWithRetry, initGraphQlHttpResponseHandler, initHttpResponseHandler };
